bayespy.nodes.GaussianGammaARD.lower_bound_contribution
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaARD.lower_bound_contribution